<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>العرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>سجل نظيف</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>هل أنت متأكد أنك تريد مسح السجل؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>تؤكد</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 أيام</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 أسبوع</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 شهر</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 أشهر</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>تصدير</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>تسجيل الدخول</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>حرج جدا</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>تتبع</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>تحديد الهوية</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>رقابة اختيارية على الوصول</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>رقابة إجبارية على الوصول</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>عابر</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>تدقيق المستندات</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>أخرى</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>اكسب (*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation> TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html) </translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>التصدير...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>تم التصدير بنجاح</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>فشل التصدير</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>مسار التصدير غير متاح. يرجى اختيار مجلد آخر لعملية التصدير.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ملف التصدير</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>الفترة :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>المستوى:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستعمل :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>سجل إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>سجل تسجيل الدخول</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>نوع التدقيق:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>التطبيق:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>الشبكة الفرعية:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>التتبع</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>حرج جدا</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>ملف السجل فارغ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>عارض السجلات</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>عارض السجلات هو أداة مفيدة لعرض سجلات النظام</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>لا يوجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>المستوى</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>معالجة</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>المستوى:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>التنفيذ:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>معلومات :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستخدم:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>اسم الملف</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>التاريخ والتعديل</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>ملف النواة</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>اسم المستخدم </translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>التغيير</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>سجل النظام</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>سجل النواة</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>سجل حزم dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>سجل Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>سجل Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>سجل التطبيقات</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>أحداث الإثلاع وإيقاف التشغيل</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>سجل dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>سجل آخر</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>سجل مخصص</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>سجل تدقيق</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>سجل كوردمب</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>لم يتمكّن الحصول على معلومات الانهيار، يرجى تثبيت systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>ليس لديك إذن لمشاهدته</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>| - مستوى الأمان الحالي للنظام: مرتفع
       يمكن لمسؤولي التدقيق فقط عرض سجل التدقيق</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation> rejuven نسخة الرقابة لا توجد.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>تصدير السجلات إلى المسار المحدد</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>مسار</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>تصدير السجلات من الأنواع المحددة</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>تصدير السجلات من التطبيقات الذاتية التي تم تطويرها</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>SELF APPNAME</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>تصدير السجلات ضمن فترة زمنية محددة</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>الفترة</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>تصدير السجلات ضمن مستوى تصحيح محدد</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>المستوى</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>حالة التشغيل</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>تصدير سجلات التشغيل (لا-klu) ضمن حالة محددة</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>تصدير أحداث التشغيل والإيقاف أو السجلات المراقبة ضمن نوع حدث محدد</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>نوع الحدث</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>تصدير السجلات بناءً على نتائج بحث الكلمات الرئيسية</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>كلمة رئيسية</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>إبلاغ معلومات تسرب الذاكرة المؤقتة</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>تصدير السجلات بناءً على نموذج التطبيق الفرعي</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>وحدة فرعية</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>فاصل التحديث</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 ثوانٍ</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 دقيقة</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 دقائق</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>لا تحديث</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>تصدير الكل</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>ترحيل الآن</translation>
    </message>
</context>
</TS>